<?php

namespace Drupal\survey\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\node\Entity\Node;

/**
 * Defines a controller for listing survey entities.
 */
class SurveyController extends ControllerBase {

  /**
   * Builds a list of survey entities.
   *
   * @return array
   *   A render array representing the survey list table.
   */
  public function listSurveys() {
    $query = \Drupal::entityQuery('node')
      ->condition('type', 'survey_content')
      ->accessCheck(TRUE)
      ->execute();

    $nodes = Node::loadMultiple($query);

    $rows = [];
    foreach ($nodes as $node) {
      $link = Link::fromTextAndUrl($node->getTitle(), Url::fromRoute('survey.survey_results', ['node' => $node->id()]))->toRenderable();
      $rows[] = [
        'data' => [
          'title' => [
            'data' => $link,
            'class' => ['title'],
          ],
        ],
      ];
    }

    return [
      '#type' => 'table',
      '#header' => [$this->t('Title')],
      '#rows' => $rows,
      '#empty' => $this->t('No surveys available.'),
    ];
  }

}
