<?php

namespace Drupal\survey\Entity\NodeType;

use Drupal\Core\Entity\Entity\EntityFormDisplay;
use Drupal\Core\Entity\Entity\EntityViewDisplay;
use Drupal\field\Entity\FieldConfig;
use Drupal\field\Entity\FieldStorageConfig;
use Drupal\node\Entity\NodeType;

/**
 * Create Answer Content type.
 */
class AnswerContent {

  /**
   * Creates the 'Answer Content' node type.
   *
   * This method initializes and saves a new node type called 'Answer Content',
   * turning off the creation of new revisions, and setting up display settings.
   */
  public static function create() {
    $node_type = NodeType::create([
      'type' => 'answer_content',
      'name' => 'Answer Content',
      'status' => TRUE,
      'new_revision' => FALSE,
      'preview_mode' => 1,
      'display_submitted' => FALSE,
    ]);
    $node_type->set('options', ['promote' => FALSE]);
    $node_type->save();

    $fields = [
      'field_answer_text' => [
        'type' => 'text_long',
        'settings' => [
          'allowed_formats' => ['basic_html'],
        ],
        'entity_type' => 'node',
        'bundle' => 'answer_content',
        'label' => 'Answer Text',
        'description' => 'The text of the answer.',
        'required' => FALSE,
        'translatable' => TRUE,
        // Single value.
        'cardinality' => 1,
      ],
    ];

    foreach ($fields as $field_name => $config) {
      $field_storage = FieldStorageConfig::create([
        'field_name' => $field_name,
        'type' => $config['type'],
        'entity_type' => $config['entity_type'],
        'settings' => $config['settings'],
        'cardinality' => $config['cardinality'],
      ]);
      $field_storage->save();

      $field_instance = FieldConfig::create([
        'field_storage' => $field_storage,
        'bundle' => $config['bundle'],
        'label' => $config['label'],
        'description' => $config['description'],
        'required' => $config['required'],
        'translatable' => $config['translatable'],
      ]);
      $field_instance->save();

    }
    $form_display = EntityFormDisplay::create([
      'targetEntityType' => 'node',
      'bundle' => 'answer_content',
      'mode' => 'default',
      'status' => TRUE,
    ]);
    $form_display->setComponent('field_answer_text', [
      'type' => 'text_textarea',
      'weight' => 1,
      'settings' => [
        'rows' => 2,
        'placeholder' => '',
      ],
    ])->setComponent('title', [
      'type' => 'string_textfield',
      'weight' => 0,
      'settings' => [
        'size' => 60,
        'placeholder' => '',
      ],
    ]);
    $form_display->save();

    $view_display = EntityViewDisplay::create([
      'targetEntityType' => 'node',
      'bundle' => 'answer_content',
      'mode' => 'default',
      'status' => TRUE,
    ]);
    $view_display->setComponent('field_answer_text', [
      'type' => 'text_default',
      'label' => 'hidden',
      'weight' => 1,
    ]);
    $view_display->save();
  }

}
