<?php

namespace Drupal\survey\Entity\NodeType;

use Drupal\Core\Entity\Entity\EntityFormDisplay;
use Drupal\field\Entity\FieldConfig;
use Drupal\field\Entity\FieldStorageConfig;
use Drupal\node\Entity\NodeType;

/**
 * Create Survey Content type.
 */
class SurveyContent {

  /**
   * Creates the 'Survey Content' node type.
   *
   * This method initializes and saves a new node type called 'Survey Content',
   * turning off the creation of new revisions, and setting up display settings.
   */
  public static function create() {
    $node_type = NodeType::create([
      'type' => 'survey_content',
      'name' => 'Survey Content',
      'status' => TRUE,
      'new_revision' => FALSE,
      'preview_mode' => 1,
      'display_submitted' => FALSE,
    ]);
    $node_type->set('options', ['promote' => FALSE]);
    $node_type->save();

    $fields = [
      'field_questions' => [
        'type' => 'entity_reference',
        'settings' => [
          'target_type' => 'node',
          'handler' => 'default:node',
          'handler_settings' => [
            'target_bundles' => ['question_content' => 'question_content'],
          ],
        ],
        'entity_type' => 'node',
        'bundle' => 'survey_content',
        'label' => 'Questions',
        'description' => 'Add questions to this survey.',
        'required' => TRUE,
        'translatable' => TRUE,
        // Unlimited.
        'cardinality' => -1,
      ],
      'field_survey_type' => [
        'type' => 'string',
        'entity_type' => 'node',
        'bundle' => 'survey_content',
        'label' => 'Enter Survey Type',
        'description' => 'Survey Type',
        'required' => FALSE,
        'translatable' => FALSE,
        'cardinality' => 1,
      ],
    ];

    foreach ($fields as $field_name => $config) {
      $field_storage = FieldStorageConfig::create([
        'field_name' => $field_name,
        'entity_type' => $config['entity_type'],
        'type' => $config['type'],
        'settings' => $config['settings'] ?? [],
        'cardinality' => $config['cardinality'],
      ]);
      $field_storage->save();
      $field_instance_settings = [];
      if ($config['type'] === 'entity_reference') {
        $field_instance_settings = [
          'handler' => 'default:node',
          'handler_settings' => [
            'target_bundles' => ['question_content' => 'question_content'],
          ] ?? [],
        ];
      }
      $field_instance = FieldConfig::create([
        'field_storage' => $field_storage,
        'bundle' => $config['bundle'],
        'label' => $config['label'],
        'description' => $config['description'],
        'required' => $config['required'],
        'translatable' => $config['translatable'],
        'settings' => $field_instance_settings,
      ]);
      $field_instance->save();
    }

    $form_display = EntityFormDisplay::create([
      'targetEntityType' => 'node',
      'bundle' => 'survey_content',
      'mode' => 'default',
      'status' => TRUE,
    ]);
    $form_display->setComponent('title', [
      'type' => 'string_textfield',
      'weight' => 0,
      'settings' => [
        'size' => 60,
        'placeholder' => '',
      ],
    ])->setComponent('field_questions', [
      'type' => 'inline_entity_form_complex',
      'weight' => 2,
      'settings' => [
        'form_mode' => 'default',
        'override_labels' => FALSE,
        'allow_new' => TRUE,
        'allow_existing' => FALSE,
        'match_operator' => 'CONTAINS',
        'allow_duplicate' => FALSE,
      ],
    ])->setComponent('field_survey_type', [
      'type' => 'string_textfield',
      'weight' => 1,
      'settings' => [
        'size' => 60,
        'placeholder' => 'Type here to search for survey types...',
      ],
    ]);
    $form_display->save();

  }

}
