<?php

namespace Drupal\survey\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form handler for the OpenAI Survey settings form.
 *
 * Provides a configuration form for setting up OpenAI API key and model
 * used in the survey module.
 */
class OpenAIConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'openai_survey_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['openai_survey.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('openai_survey.settings');

    $form['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('OpenAI API Key'),
      '#default_value' => $config->get('api_key'),
      '#required' => TRUE,
    ];

    $form['model'] = [
      '#type' => 'textfield',
      '#title' => $this->t('OpenAI Model'),
      '#default_value' => $config->get('model'),
      '#required' => TRUE,
      '#description' => $this->t('Enter the OpenAI model you want to use, such as "davinci", "gpt-3.5-turbo", "gpt-4", "gpt-4-32k", etc.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * Builds the form for OpenAI Survey configuration settings.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('openai_survey.settings')
      ->set('api_key', $form_state->getValue('api_key'))
      ->set('model', $form_state->getValue('model'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
