<?php

namespace Drupal\survey\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\node\Entity\Node;
use Drupal\node\NodeInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a 'SurveyFormBlock' block.
 *
 * @Block(
 *   id = "survey_form_block",
 *   admin_label = @Translation("Survey Form Block"),
 *   category = @Translation("Custom Survey Blocks")
 * )
 */
class SurveyFormBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The form builder.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * Constructs a new SurveyFormBlock instance.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Form\FormBuilderInterface $formBuilder
   *   The form builder service.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, FormBuilderInterface $formBuilder) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->formBuilder = $formBuilder;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('form_builder')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $node_id = $this->configuration['survey_node'] ?? NULL;
    $form['survey_node'] = [
      '#type' => 'entity_autocomplete',
      '#title' => $this->t('Select Survey Node'),
      '#target_type' => 'node',
      '#selection_settings' => [
        'target_bundles' => ['survey_content'],
      ],
      '#default_value' => $node_id ? Node::load($node_id) : NULL,
      '#required' => TRUE,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->configuration['survey_node'] = $form_state->getValue('survey_node');
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $node_id = $this->configuration['survey_node'];
    if ($node_id) {
      $node = Node::load($node_id);
      if ($node instanceof NodeInterface && $node->bundle() === 'survey_content') {
        return $this->formBuilder->getForm('Drupal\survey\Form\SurveyForm', $node);
      }
    }
    return [
      '#markup' => $this->t('No valid survey content found or the node is not of type "survey_content".'),
    ];
  }

}
